<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/urls?lang_cible=en
// ** ne pas modifier le fichier **

return [

	// A
	'actualiser_toutes' => 'Update all urls',
	'actualiser_toutes_explication' => 'You can re-process the URLs.
		If a URL has changed, a new entry will be created (without loosing the URLs already 
		present and without affecting the manually defined URLs).',

	// B
	'bouton_supprimer_url' => 'Delete this URL',

	// E
	'erreur_arbo_2_segments_max' => 'You can’t use more than two URL segments for an object',
	'erreur_config_url_forcee' => 'The configuration of URLs is fixed in the <tt>mes_options.php</tt> file.',
	'explication_editer' => 'The advanced management of URLs allows you to edit the URL of the pages of each editorial object, and to manage the history of their evolution.',

	// I
	'icone_configurer_urls' => 'Setup the URLs',
	'icone_controler_urls' => 'Meaningfull URLs',
	'info_1_url' => '1 URL',
	'info_id_parent' => '#parent',
	'info_nb_urls' => '@nb@ URLs',
	'info_objet' => 'Object',

	// L
	'label_tri_date' => 'Date',
	'label_tri_id' => 'ID',
	'label_tri_perma' => 'Locked URLs',
	'label_tri_url' => 'URL',
	'label_url' => 'New URL',
	'label_url_minuscules_0' => 'Keep the title case',
	'label_url_minuscules_1' => 'Forcing lowercase urls',
	'label_url_permanente' => 'Lock this URL (no update after modification of the object)',
	'label_url_sep_id' => 'Character to separate the number added in case of duplicate',
	'label_urls_activer_controle_oui' => 'Enable advanced management of URLs',
	'label_urls_nb_max_car' => 'Maximum number of characters',
	'label_urls_nb_min_car' => 'Minimum number of characters',
	'liberer_url' => 'Release',
	'liste_des_urls' => 'All URLs',

	// T
	'texte_type_urls' => 'You may choose how page URLs are to be calculated.',
	'texte_type_urls_attention' => 'Warning: this setting will only work if the file @htaccess@ is correctly installed in the site’s root directory.',
	'texte_urls_nb_max_car' => 'If the title is longer, it will be cut.',
	'texte_urls_nb_min_car' => 'If the title is shorter, it’s its identifying number which will be used.',
	'titre_gestion_des_urls' => 'URLs management',
	'titre_type_arbo' => 'Arborescent URLs',
	'titre_type_html' => 'HTML objects URLs ',
	'titre_type_libres' => 'Free URLs',
	'titre_type_page' => 'Page URLs',
	'titre_type_propres' => 'Friendly URLs',
	'titre_type_propres2' => 'Friendly +<tt>.html</tt>',
	'titre_type_propres_qs' => 'Friendly in query-string URLs',
	'titre_type_simple' => 'Simple URLs',
	'titre_type_standard' => 'Historical URLs',
	'titre_type_urls' => 'Type of URL addresses',
	'tout_voir' => 'Show all URLs',

	// U
	'url_ajout_impossible' => 'An error has occurred. This URL couldn’t be saved',
	'url_ajoutee' => 'The URL has been added',

	// V
	'verifier_url_nettoyee' => 'The URL has been corrected, you can check before saving.',
	'verrouiller_url' => 'Lock',
];
